'
' Effority.Net ( http://www.effority.net )
' Benjamin Hermann, Oliver Dembniak
'
' Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated 
' documentation files (the "Software"), to deal in the Software without restriction, including without limitation 
' the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and 
' to permit persons to whom the Software is furnished to do so, subject to the following conditions:
'
' The above copyright notice and this permission notice shall be included in all copies or substantial portions 
' of the Software.
'
' THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED 
' TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
' THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF 
' CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
' DEALINGS IN THE SOFTWARE.
'

Namespace effority.Ealo.Specialized

    Public Class Tabs
        Inherits EaloBase

        Public Shared Function GetAllTabsAsDictionary(ByVal Locale As String) As Generic.Dictionary(Of Int32, effority.Ealo.Specialized.TabInfo)

            Return GetAllTabsAsDictionary(Locale, True)

        End Function

        Public Shared Function GetAllTabsAsDictionary(ByVal Locale As String, ByVal FromCache As Boolean) As Generic.Dictionary(Of Int32, effority.Ealo.Specialized.TabInfo)

            Dim dic As New Generic.Dictionary(Of Int32, effority.Ealo.Specialized.TabInfo)

            Dim Liste As Generic.List(Of effority.Ealo.Specialized.TabInfo) = GetAllTabsAsListe(Locale, FromCache)

            For Each info As DotNetNuke.Entities.Tabs.TabInfo In Liste

                dic.Add(info.TabID, info)

            Next

            Return dic

        End Function

        ''' -----------------------------------------------------------------------------
        ''' <summary>
        '''    Loads localized TabInfos
        '''    Tabname and Tabtile will be localized
        '''    Fallback is DNN standard value
        ''' </summary>
        ''' <remarks>
        ''' </remarks>
        ''' <history>
        ''' 	[odem] 01/2008	Created
        ''' </history>
        ''' -----------------------------------------------------------------------------
        Public Shared Function GetAllTabsAsListe(ByVal Locale As String) As Generic.List(Of effority.Ealo.Specialized.TabInfo)

            Return GetAllTabsAsListe(Locale, True)

        End Function
        ''' -----------------------------------------------------------------------------
        ''' <summary>
        '''    Loads localized TabInfos
        '''    Tabname and Tabtile will be localized
        '''    Fallback is DNN standard value
        ''' </summary>
        ''' <remarks>
        ''' </remarks>
        ''' <history>
        ''' 	[odem] 01/2008	Created
        ''' </history>
        ''' -----------------------------------------------------------------------------
        Public Shared Function GetAllTabsAsListe(ByVal Locale As String, ByVal FromCache As Boolean) As Generic.List(Of effority.Ealo.Specialized.TabInfo)

            Dim pCont As New DotNetNuke.Entities.Portals.PortalController

            Dim portals As ArrayList = pCont.GetPortals()

            Dim liste As New Generic.List(Of effority.Ealo.Specialized.TabInfo)

            For Each portal As DotNetNuke.Entities.Portals.PortalInfo In portals

                liste.AddRange(GetTabsAsListe(portal.PortalID, Locale, FromCache))

            Next

            Return liste

        End Function

        ''' -----------------------------------------------------------------------------
        ''' <summary>
        '''    Loads localized TabInfos
        '''    Tabname and Tabtile will be localized
        '''    Fallback is DNN standard value
        ''' </summary>
        ''' <remarks>
        ''' </remarks>
        ''' <history>
        ''' 	[odem] 07/2004	Created
        ''' </history>
        ''' -----------------------------------------------------------------------------
        Public Shared Function GetTabsAsListe(ByVal PortalId As Int32, ByVal Locale As String) As Generic.List(Of effority.Ealo.Specialized.TabInfo)

            Return GetTabsAsListe(PortalId, Locale, True)

        End Function

        ''' -----------------------------------------------------------------------------
        ''' <summary>
        '''    Loads localized TabInfos
        '''    Tabname and Tabtile will be localized
        '''    Fallback is DNN standard value
        ''' </summary>
        ''' <remarks>
        ''' </remarks>
        ''' <history>
        ''' 	[odem] 07/2004	Created
        ''' </history>
        ''' -----------------------------------------------------------------------------
        Public Shared Function GetTabsAsListe(ByVal PortalId As Int32, ByVal Locale As String, ByVal FromCache As Boolean) As Generic.List(Of effority.Ealo.Specialized.TabInfo)

            Dim dic As Generic.Dictionary(Of String, StringInfo) = effority.Ealo.Controller.GetStringsByQualifier(TabQualifier, Locale, FromCache)

            Dim dicTabTitle As Generic.Dictionary(Of String, StringInfo) = effority.Ealo.Controller.GetStringsByQualifier(TabTitleQualifier, Locale, FromCache)

            Dim tabController As New DotNetNuke.Entities.Tabs.TabController

            Dim tabDic As Generic.Dictionary(Of Integer, DotNetNuke.Entities.Tabs.TabInfo) = tabController.GetTabsByPortal(PortalId)

            Dim neueListe As New Generic.List(Of effority.Ealo.Specialized.TabInfo)

            For Each info As DotNetNuke.Entities.Tabs.TabInfo In tabDic.Values

                Dim localizedTabName As StringInfo
                Dim localizedTabTitle As StringInfo

                Dim tabInfo As New effority.Ealo.Specialized.TabInfo(info.Clone)

                ' TabNames
                If dic.TryGetValue(CStr(info.TabID), localizedTabName) Then

                    If Not String.IsNullOrEmpty(localizedTabName.StringText) Then

                        ' Fallback wird auf den DNN Wert gendert
                        localizedTabName.FallBack = tabInfo.TabName
                        localizedTabName.FallbackIsNull = False

                        tabInfo.EaloTabName = localizedTabName

                    End If

                End If

                ' TabTitles
                If dicTabTitle.TryGetValue(CStr(info.TabID), localizedTabTitle) Then

                    If Not String.IsNullOrEmpty(localizedTabTitle.StringText) Then

                        localizedTabTitle.FallBack = tabInfo.TabName
                        localizedTabTitle.FallbackIsNull = False

                        tabInfo.EaloTitle = localizedTabTitle

                    End If

                End If

                neueListe.Add(tabInfo)

            Next

            Return neueListe

        End Function

        Public Shared Function GetTabsAsDictionary(ByVal PortalId As Int32, ByVal Locale As String) As Generic.Dictionary(Of Int32, effority.Ealo.Specialized.TabInfo)

            Return GetTabsAsDictionary(PortalId, Locale, True)

        End Function

        Public Shared Function GetTabsAsDictionary(ByVal PortalId As Int32, ByVal Locale As String, ByVal FromCache As Boolean) As Generic.Dictionary(Of Int32, effority.Ealo.Specialized.TabInfo)

            Dim dic As New Generic.Dictionary(Of Int32, effority.Ealo.Specialized.TabInfo)

            Dim Liste As Generic.List(Of effority.Ealo.Specialized.TabInfo) = GetTabsAsListe(PortalId, Locale, FromCache)

            For Each info As DotNetNuke.Entities.Tabs.TabInfo In Liste

                dic.Add(info.TabID, info)

            Next

            Return dic

        End Function

        Public Shared Function LocalizedTabList(ByVal Tabs As ArrayList, ByVal Locale As String, ByVal FromCache As Boolean) As List(Of effority.Ealo.Specialized.TabInfo)

            Dim newList As New List(Of DotNetNuke.Entities.Tabs.TabInfo)

            For Each dnnTab As DotNetNuke.Entities.Tabs.TabInfo In Tabs
                newList.Add(dnnTab)
            Next

            Return LocalizedTabList(newList, Locale, FromCache)

        End Function

        Public Shared Function LocalizedTabList(ByVal Tabs As List(Of DotNetNuke.Entities.Tabs.TabInfo), ByVal Locale As String, ByVal FromCache As Boolean) As List(Of effority.Ealo.Specialized.TabInfo)

            Dim dic As Generic.Dictionary(Of String, StringInfo) = effority.Ealo.Controller.GetStringsByQualifier(TabQualifier, Locale, FromCache)

            Dim dicTabTitle As Generic.Dictionary(Of String, StringInfo) = effority.Ealo.Controller.GetStringsByQualifier(TabTitleQualifier, Locale, FromCache)

            Dim neueListe As New Generic.List(Of effority.Ealo.Specialized.TabInfo)

            For Each info As DotNetNuke.Entities.Tabs.TabInfo In Tabs

                Dim localizedTabName As StringInfo
                Dim localizedTabTitle As StringInfo

                Dim tabInfo As New effority.Ealo.Specialized.TabInfo(info.Clone)

                '' TabNames
                If dic.TryGetValue(CStr(info.TabID), localizedTabName) Then

                    tabInfo.EaloTabName = localizedTabName

                End If

                'End If

                '' TabTitles
                If dicTabTitle.TryGetValue(CStr(info.TabID), localizedTabTitle) Then

                    tabInfo.EaloTitle = localizedTabTitle

                End If

                'End If

                neueListe.Add(tabInfo)

            Next

            Return neueListe

        End Function

        Public Shared Sub UpdateTab(ByVal TabId As Int32, ByVal TabName As String, ByVal Title As String, ByVal Locale As String)

            ' Werte werden aktualisiert / beide leeren Werte werden vorhandene Datenstze gelscht

            Dim nameInfo As StringInfo = effority.Ealo.Controller.GetStringByQualifierAndStringName(TabQualifier, CStr(TabId), Locale, False)

            If Not String.IsNullOrEmpty(Locale) Then

                If Not String.IsNullOrEmpty(TabName) Then

                    ' Neuen Wert einfgen / Wert aktualisieren
                    effority.Ealo.Controller.UpdateStringByQualiferAndStringName(TabQualifier, CStr(TabId), TabName, Locale, True)

                Else

                    If Not nameInfo Is Nothing Then

                        ' Wert lschen
                        effority.Ealo.Controller.DeleteByQualifierAndStringNameAndLocale(TabQualifier, CStr(TabId), Locale)

                    End If

                End If


            End If

            ' Title
            Dim nameTitle As StringInfo = effority.Ealo.Controller.GetStringByQualifierAndStringName(TabTitleQualifier, CStr(TabId), Locale, False)

            If Not String.IsNullOrEmpty(Locale) Then

                If Not String.IsNullOrEmpty(Title) Then
                    ' Neuen Wert einfgen / Wert aktualisieren
                    effority.Ealo.Controller.UpdateStringByQualiferAndStringName(TabTitleQualifier, CStr(TabId), Title, Locale, True)
                Else

                    If Not nameTitle Is Nothing Then
                        ' Wert lschen

                        effority.Ealo.Controller.DeleteByQualifierAndStringNameAndLocale(TabTitleQualifier, CStr(TabId), Locale)

                    End If

                End If

            End If

        End Sub

    End Class

    Public Class TabInfo
        Inherits DotNetNuke.Entities.Tabs.TabInfo

        Private _TabName As StringInfo
        Private _Title As StringInfo

        Private Sub ImportDNNTabInfo(ByVal DNNTabInfo As DotNetNuke.Entities.Tabs.TabInfo)

            ' assign the property values
            MyBase.TabID = DNNTabInfo.TabID
            MyBase.TabOrder = DNNTabInfo.TabOrder
            MyBase.PortalID = DNNTabInfo.PortalID
            MyBase.TabName = DNNTabInfo.TabName
            MyBase.AuthorizedRoles = DNNTabInfo.AuthorizedRoles
            MyBase.IsVisible = DNNTabInfo.IsVisible
            MyBase.ParentId = DNNTabInfo.ParentId
            MyBase.Level = DNNTabInfo.Level
            MyBase.IconFile = DNNTabInfo.IconFile
            MyBase.AdministratorRoles = DNNTabInfo.AdministratorRoles
            MyBase.DisableLink = DNNTabInfo.DisableLink
            MyBase.Title = DNNTabInfo.Title
            MyBase.Description = DNNTabInfo.Description
            MyBase.KeyWords = DNNTabInfo.KeyWords
            MyBase.IsDeleted = DNNTabInfo.IsDeleted
            MyBase.Url = DNNTabInfo.Url
            MyBase.SkinSrc = DNNTabInfo.SkinSrc
            MyBase.ContainerSrc = DNNTabInfo.ContainerSrc
            MyBase.TabPath = DNNTabInfo.TabPath
            MyBase.StartDate = DNNTabInfo.StartDate
            MyBase.EndDate = DNNTabInfo.EndDate
            MyBase.TabPermissions = DNNTabInfo.TabPermissions
            MyBase.HasChildren = DNNTabInfo.HasChildren
            MyBase.SkinPath = DNNTabInfo.SkinPath
            MyBase.ContainerPath = DNNTabInfo.ContainerPath
            MyBase.IsSuperTab = DNNTabInfo.IsSuperTab
            MyBase.RefreshInterval = DNNTabInfo.RefreshInterval
            MyBase.PageHeadText = DNNTabInfo.PageHeadText
            If Not DNNTabInfo.BreadCrumbs Is Nothing Then
                MyBase.BreadCrumbs = New ArrayList
                For Each t As TabInfo In DNNTabInfo.BreadCrumbs
                    MyBase.BreadCrumbs.Add(t.Clone())
                Next
            End If

            ' initialize collections which are populated later
            MyBase.Panes = New ArrayList
            MyBase.Modules = New ArrayList

        End Sub

        Public Sub New(ByVal DNNTabInfo As DotNetNuke.Entities.Tabs.TabInfo)
            Me.ImportDNNTabInfo(DNNTabInfo)
        End Sub


        Public Property EaloTabName() As StringInfo
            Get
                Return _TabName
            End Get
            Set(ByVal value As StringInfo)
                _TabName = value
            End Set
        End Property

        Public Property EaloTitle() As StringInfo
            Get
                Return _Title
            End Get
            Set(ByVal value As StringInfo)
                _Title = value
            End Set
        End Property

    End Class

End Namespace
